use std::process::ExitCode;
use std::str::FromStr;

use anyhow::{anyhow, bail};
use clap::Args;
use itertools::Itertools;
use pkgcraft::config::Config;
use pkgcraft::dep::Dep;

#[derive(Debug, Args)]
pub struct Command {
    compare: String,
}

impl Command {
    pub(super) fn run(&self, _config: &Config) -> anyhow::Result<ExitCode> {
        let (s1, op, s2) = self
            .compare
            .split_whitespace()
            .collect_tuple()
            .ok_or_else(|| anyhow!("invalid comparison format: {}", self.compare))?;
        let d1 = Dep::from_str(s1)?;
        let d2 = Dep::from_str(s2)?;
        let result = match op {
            "<" => d1 < d2,
            "<=" => d1 <= d2,
            "==" => d1 == d2,
            "!=" => d1 != d2,
            ">=" => d1 >= d2,
            ">" => d1 > d2,
            _ => bail!("invalid operator: {op}"),
        };
        Ok(ExitCode::from(!result as u8))
    }
}
